@@ -1,6 +1,6 @@
 package App::ListOrgHeadlines;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 use Log::Any qw($log);
@@ -16,7 +16,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(list_org_headlines);
 
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 our %SPEC;
 
@@ -350,7 +350,10 @@ sub list_org_headlines {
         $res = [map {$_->[0]} @res];
     }
 
-    [200, "OK", $res, {result_format_options=>{list_max_columns=>1}}];
+    [200, "OK", $res, {result_format_options=>{
+        "text"        => {list_max_columns=>1},
+        "text-pretty" => {list_max_columns=>1},
+    }}];
 }
 
 1;
@@ -365,7 +368,7 @@ App::ListOrgHeadlines - List headlines in Org files
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -377,117 +380,10 @@ version 0.16
 
 None are exported, but they are exportable.
 
-=head1 DESCRIPTION
 
+=head2 list_org_headlines() -> [status, msg, result, meta]
 
-This module has L<Rinci> metadata.
-
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
-=head2 list_org_headlines(%args) -> [status, msg, result, meta]
-
-List all headlines in all Org files.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<cache_dir> => I<str>
-
-Cache Org parse result.
-
-Since Org::Parser can spend some time to parse largish Org files, this is an
-option to store the parse result. Caching is turned on if this argument is set.
-
-=item * B<detail> => I<bool> (default: 0)
-
-Show details instead of just titles.
-
-=item * B<done> => I<bool>
-
-Only show todo items that are done.
-
-=item * B<due_in> => I<int>
-
-Only show todo items that are (nearing|passed) due.
-
-If value is not set, then will use todo item's warning period (or, if todo item
-does not have due date or warning period in its due date, will use the default
-14 days).
-
-If value is set to something smaller than the warning period, the todo item will
-still be considered nearing due when the warning period is passed. For example,
-if today is 2011-06-30 and due_in is set to 7, then todo item with due date
- won't pass the filter (it's still 10 days in the future, larger
-than 7) but  will (warning period 14 days is already
-passed by that time).
-
-=item * B<files>* => I<array>
-
-=item * B<from_level> => I<int> (default: 1)
-
-Only show headlines having this level as the minimum.
-
-=item * B<group_by_tags> => I<bool> (default: 0)
-
-Whether to group result by tags.
-
-If set to true, instead of returning a list, this function will return a hash of
-lists, keyed by tag: {tag1: [hl1, hl2, ...], tag2: [...]}. Note that some
-headlines might be listed more than once if it has several tags.
-
-=item * B<has_tags> => I<array>
-
-Only show headlines that have the specified tags.
-
-=item * B<lacks_tags> => I<array>
-
-Only show headlines that don't have the specified tags.
-
-=item * B<priority> => I<str>
-
-Only show todo items that have this priority.
-
-=item * B<sort> => I<any> (default: "due_date")
-
-Specify sorting.
-
-If string, must be one of 'dueI<date', '-due>date' (descending).
-
-If code, sorting code will get [REC, DUEI<DATE, HL] as the items to compare,
-where REC is the final record that will be returned as final result (can be a
-string or a hash, if 'detail' is enabled), DUE>DATE is the DateTime object (if
-any), and HL is the Org::Headline object.
-
-=item * B<state> => I<str>
-
-Only show todo items that have this state.
-
-=item * B<time_zone> => I<str>
-
-Will be passed to parser's options.
-
-If not set, TZ environment variable will be picked as default.
-
-=item * B<to_level> => I<int>
-
-Only show headlines having this level as the maximum.
-
-=item * B<today> => I<any>
-
-Assume today's date.
-
-You can provide Unix timestamp or DateTime object. If you provide a DateTime
-object, remember to set the correct time zone.
-
-=item * B<todo> => I<bool>
-
-Only show headlines that are todos.
-
-=back
+No arguments.
 
 Return value:
 
